# eric7.Plugins.VcsPlugins.vcsSubversion.SvnCopyDialog

Module implementing a dialog to enter the data for a copy operation.

### Global Attributes

None

### Classes

SvnCopyDialog | Class implementing a dialog to enter the data for a copy or rename operation.

### Functions

None

## SvnCopyDialog

Class implementing a dialog to enter the data for a copy or rename operation.

### Derived from

QDialog, Ui_SvnCopyDialog

### Class Attributes

None

### Class Methods

None

### Methods

SvnCopyDialog | Constructor
getData | Public method to retrieve the copy data.
on_targetPicker_textChanged | Private slot to handle changes of the target.

### Static Methods

None

#### SvnCopyDialog (Constructor)

SvnCopyDialog(source, parent=None, move=False, force=False)

Constructor

source
  name of the source file/directory (string)
parent
  parent widget (QWidget)
move
  flag indicating a move operation (boolean)
force
  flag indicating a forced operation (boolean)

#### SvnCopyDialog.getData

getData()

Public method to retrieve the copy data.

Return:
  the target name (string) and a flag indicating the operation should be enforced (boolean)

#### SvnCopyDialog.on_targetPicker_textChanged

on_targetPicker_textChanged(txt)

Private slot to handle changes of the target.

txt
  contents of the target edit (string)

Up